@@ -24,7 +24,8 @@ from django.utils.importlib import import_module
 
 import nose.core
 
-from django_nose.plugin import DjangoSetUpPlugin, ResultPlugin
+from django_nose.plugin import DjangoSetUpPlugin, ResultPlugin, TestReorderer
+from django_nose.utils import uses_mysql
 
 try:
     any
@@ -36,7 +37,7 @@ except NameError:
         return False
 
 
-__all__ = ['BasicNoseRunner', 'NoseTestSuiteRunner', 'uses_mysql']
+__all__ = ['BasicNoseRunner', 'NoseTestSuiteRunner']
 
 
 # This is a table of Django's "manage.py test" options which
@@ -44,10 +45,6 @@ __all__ = ['BasicNoseRunner', 'NoseTestSuiteRunner', 'uses_mysql']
 OPTION_TRANSLATION = {'--failfast': '-x'}
 
 
-def uses_mysql(connection):
-    return 'mysql' in connection.settings_dict['ENGINE']
-
-
 # Django v1.2 does not have a _get_test_db_name() function.
 if not hasattr(BaseDatabaseCreation, '_get_test_db_name'):
     def _get_test_db_name(self):
@@ -61,7 +58,7 @@ if not hasattr(BaseDatabaseCreation, '_get_test_db_name'):
 
 
 def _get_plugins_from_settings():
-    for plg_path in list(getattr(settings, 'NOSE_PLUGINS', [])) + ['django_nose.fixture_bundling.FixtureBundlingPlugin']:
+    for plg_path in list(getattr(settings, 'NOSE_PLUGINS', [])) + ['django_nose.plugin.TestReorderer']:
         try:
             dot = plg_path.rindex('.')
         except ValueError:
@@ -109,7 +106,9 @@ class BasicNoseRunner(DjangoTestSuiteRunner):
 
     def run_suite(self, nose_argv):
         result_plugin = ResultPlugin()
-        plugins_to_add = [DjangoSetUpPlugin(self), result_plugin]
+        plugins_to_add = [DjangoSetUpPlugin(self),
+                          result_plugin,
+                          TestReorderer()]
 
         for plugin in _get_plugins_from_settings():
             plugins_to_add.append(plugin)
@@ -119,13 +118,12 @@ class BasicNoseRunner(DjangoTestSuiteRunner):
         return result_plugin.result
 
     def run_tests(self, test_labels, extra_tests=None):
-        """
-        Run the unit tests for all the test names in the provided list.
+        """Run the unit tests for all the test names in the provided list.
 
         Test names specified may be file or module names, and may optionally
         indicate the test case to run by separating the module or file name
         from the test case name with a colon. Filenames may be relative or
-        absolute.  Examples:
+        absolute. Examples:
 
         runner.run_tests('test.module')
         runner.run_tests('another.test:TestCase.test_method')
@@ -133,6 +131,7 @@ class BasicNoseRunner(DjangoTestSuiteRunner):
         runner.run_tests('/path/to/test/file.py:test_function')
 
         Returns the number of tests that failed.
+
         """
         nose_argv = (['nosetests', '--verbosity', str(self.verbosity)]
                      + list(test_labels))
@@ -140,7 +139,7 @@ class BasicNoseRunner(DjangoTestSuiteRunner):
             nose_argv.extend(settings.NOSE_ARGS)
 
         # Skip over 'manage.py test' and any arguments handled by django.
-        django_opts = ['--noinput']
+        django_opts = ['--noinput', '--liveserver']
         for opt in BaseCommand.option_list:
             django_opts.extend(opt._long_opts)
             django_opts.extend(opt._short_opts)
@@ -207,7 +206,7 @@ def _skip_create_test_db(self, verbosity=1, autoclobber=False):
 
 def _reusing_db():
     """Return whether the ``REUSE_DB`` flag was passed"""
-    return (os.getenv('REUSE_DB', 'false').lower() in ('true', '1', ''))
+    return os.getenv('REUSE_DB', 'false').lower() in ('true', '1', '')
 
 
 def _can_support_reuse_db(connection):
@@ -285,6 +284,14 @@ class NoseTestSuiteRunner(BasicNoseRunner):
             if _should_create_database(connection):
                 # We're not using _skip_create_test_db, so put the DB name back:
                 connection.settings_dict['NAME'] = orig_db_name
+
+                # Since we replaced the connection with the test DB, closing
+                # the connection will avoid pooling issues with SQLAlchemy. The
+                # issue is trying to CREATE/DROP the test database using a
+                # connection to a DB that was established with that test DB.
+                # MySQLdb doesn't allow it, and SQLAlchemy attempts to reuse
+                # the existing connection from its pool.
+                connection.close()
             else:
                 # Reset auto-increment sequences. Apparently, SUMO's tests are
                 # horrid and coupled to certain numbers.
